﻿using Kivii.DataAnnotations;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Kivii.Samples.Entities
{
    [Api(Description = "样品路由")]
    [Alias(Configs.TableNameRoute)]
    public class Route: EntityWithMetadata, IEntityHasBiz, IEntityInAssemblyDb, IEntityHasRemark, IEntityHasCreator, IEntityHasUpdater
    {
        [ApiMember(Description = "样品名称")]
        [IgnoreUpdate]
        [StringLength(200), Default("")]
        public string SampleName { get; set; }

        [ApiMember(Description = "样品Kvid")]
        [DefaultEmptyGuid]
        public Guid SampleKvid { get; set; }

        [ApiMember(Description = "主样品Kvid")]
        [DefaultEmptyGuid]
        public Guid SampleRootKvid { get; set; }

        [ApiMember(Description = "父级样品Kvid")]
        [DefaultEmptyGuid]
        public Guid SampleParentKvid { get; set; }

        #region 第三方关联V1.0
        [ApiMember(Description = "关联业务,例如:此样品用于具体某一报告,此处记录报告信息")]
        [InternalSetter]
        [StringLength(200), Default("")]
        public string BizId { get; set; }

        [ApiMember(Description = "业务Kvid")]
        [InternalSetter]
        [DefaultEmptyGuid]
        public Guid BizKvid { get; set; }

        [ApiMember(Description = "业务类型,指实体类型全名称")]
        [InternalSetter]
        [StringLength(200), Default("")]
        public string BizType { get; set; }
        #endregion

        #region 基本信息
        [ApiMember(Description = "样品路由标题")]
        [StringLength(200), Required]
        public string Title { get; set; }

        /// <summary>
        /// 送样，快递等
        /// </summary>
        [ApiMember(Description = "样品路由类型")]
        [StringLength(50)]
        public string Type { get; set; }

        /// <summary>
        /// 当前路由地点
        /// </summary>
        [ApiMember(Description = "当前路由地点")]
        [StringLength(200), Required]
        public string CurrentLocationTitle { get; set; }

        [ApiMember(Description = "当前路由地点Kvid")]
        [DefaultEmptyGuid]
        public Guid CurrentLocationKvid { get; set; }

        /// <summary>
        /// 目标地点,目标节点是下一个节点产生后返写的,代表此样品已经从当前节点离开
        /// </summary>
        [ApiMember(Description = "目标路由地点")]
        [StringLength(200)]
        public string NextLocationTitle { get; set; }

        [ApiMember(Description = "目标路由地点Kvid")]
        [DefaultEmptyGuid]
        public Guid NextLocationKvid { get; set; }

        /// <summary>
        /// 操作人
        /// </summary>
        [ApiMember(Description = "操作人")]
        [StringLength(100), Default("")]
        public string OperatorName { get; set; }

        /// <summary>
        /// 操作人Kvid
        /// </summary>
        [ApiMember(Description = "操作人Kvid")]
        public Guid OperatorKvid { get; set; }

        /// <summary>
        /// 操作日期
        /// </summary>
        [ApiMember(Description = "操作日期")]
        public DateTime OperateTime { get; set; }

        /// <summary>
        /// 摘要
        /// </summary>
        [ApiMember(Description = "摘要")]
        [StringLength(1000), Default("")]
        public string Summary { get; set; }

        [ApiMember(Description = "备注")]
        [StringLength(1000), Default("")]
        public string Remark { get; set; }

        [ApiMember(Description = "创建人Kvid ")]
        [IgnoreUpdate]
        [CurrentMemberKvid]
        public Guid CreatorKvid { get; set; }

        [ApiMember(Description = "创建人")]
        [IgnoreUpdate]
        [StringLength(50), CurrentMemberName]
        public string CreatorName { get; set; }

        [ApiMember(Description = "更新人Kvid ")]
        [CurrentMemberKvid]
        public Guid UpdaterKvid { get; set; }

        [ApiMember(Description = "更新人")]
        [StringLength(50), CurrentMemberName]
        public string UpdaterName { get; set; }
        #endregion
    }
}
